.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

layout
======

Defined in ``xtensor/xlayout.hpp``

.. doxygenenum:: xt::layout_type
   :project: xtensor

.. doxygenfunction:: xt::compute_layout(Args... args)
   :project: xtensor

xcontainer
==========

Defined in ``xtensor/xcontainer.hpp``

.. doxygenclass:: xt::xcontainer
   :project: xtensor
   :members:

xstrided_container
==================

Defined in ``xtensor/xcontainer.hpp``

.. doxygenclass:: xt::xstrided_container
   :project: xtensor
   :members:

